@@ -1669,12 +1669,13 @@ void run_instance
 						ret = CallasDonnerhackeFinneyShawThayerRFC4880::
 							SymmetricDecryptAEAD(esk->encrypted_key, esk_seskey,
 								esk->skalgo, esk->aeadalgo, 0, esk->iv, ad,
-								decrypted_key);
+								opt_verbose, decrypted_key);
 					}
 					if (ret)
 					{
-						std::cerr << "ERROR: SymmetricDecrypt() failed" <<
-							" with rc = " << gcry_err_code(ret) << std::endl;
+						std::cerr << "ERROR: SymmetricDecrypt[AEAD]() failed" <<
+							" with rc = " << gcry_err_code(ret) <<
+							" str = " << gcry_strerror(ret) << std::endl;
 						delete msg;
 						delete dkg;
 						delete ring;
