@@ -61,14 +61,14 @@ bool						instance_forked = false;
 tmcg_openpgp_secure_string_t	passphrase;
 std::string						userid, passwords, hostname, port;
 int 							opt_verbose = 0;
-bool							opt_y = false;
+bool							opt_y = false, opt_timestamping = false;
 char							*opt_crs = NULL;
 char							*opt_passwords = NULL;
 char							*opt_hostname = NULL;
 unsigned long int				opt_t = DKGPG_MAX_N, opt_s = DKGPG_MAX_N;
 unsigned long int				opt_e = 0, opt_p = 55000, opt_W = 5;
 
-bool							fips = false;
+bool							fips = false, rfc = false;
 std::stringstream				crss;
 mpz_t 							cache[TMCG_MAX_SSRANDOMM_CACHE], cache_mod;
 size_t							cache_avail = 0;
@@ -84,11 +84,20 @@ void run_instance
 		// create VTMF instance from CRS
 		BarnettSmartVTMF_dlog *vtmf;
 		if (fips)
+		{
 			vtmf = new BarnettSmartVTMF_dlog(crss, TMCG_DDH_SIZE, TMCG_DLSE_SIZE,
 				false); // without VTMF-verifiable generation of $g$ (FIPS mode)
-		else	
+		}
+		else if (rfc)
+		{
+			vtmf = new BarnettSmartVTMF_dlog_GroupQR(crss, TMCG_DDH_SIZE,
+				TMCG_DLSE_SIZE);
+		}
+		else
+		{
 			vtmf = new BarnettSmartVTMF_dlog(crss, TMCG_DDH_SIZE, TMCG_DLSE_SIZE,
 				true); // with VTMF-verifiable generation of $g$ (VTMF-vgog)
+		}
 		// check the constructed VTMF instance
 		if (!vtmf->CheckGroup())
 		{
@@ -104,6 +113,8 @@ void run_instance
 			hashalgo = TMCG_OPENPGP_HASHALGO_SHA384; // SHA384 (alg 9)
 		else if (mpz_sizeinbase(vtmf->q, 2L) == 512)
 			hashalgo = TMCG_OPENPGP_HASHALGO_SHA512; // SHA512 (alg 10)
+//		else if (mpz_sizeinbase(vtmf->q, 2L) > 1024)
+//			hashalgo = TMCG_OPENPGP_HASHALGO_SHA512; // SHA512 (alg 10) FIXME: we need dynamic hashsize here! SHAKE
 		else
 		{
 			std::cerr << "ERROR: selecting hash algorithm failed for |q| = " <<
@@ -211,6 +222,8 @@ void run_instance
 			FingerprintCompute(pub_hashing, issuer);
 		CallasDonnerhackeFinneyShawThayerRFC4880::PacketUidEncode(userid, uid);
 		dsaflags.push_back(0x01 | 0x02);
+		if (opt_timestamping)
+			dsaflags.push_back(0x08); // "This key may be used for timestamping"
 		sigtime = time(NULL); // current time
 		CallasDonnerhackeFinneyShawThayerRFC4880::
 			PacketSigPrepareSelfSignature(TMCG_OPENPGP_SIGNATURE_POSITIVE_CERTIFICATION,
@@ -443,11 +456,20 @@ void run_instance
 	// create VTMF instance from CRS
 	BarnettSmartVTMF_dlog *vtmf;
 	if (fips)
+	{
 		vtmf = new BarnettSmartVTMF_dlog(crss, TMCG_DDH_SIZE, TMCG_DLSE_SIZE,
 			false); // without VTMF-verifiable generation of $g$ (FIPS mode)
-	else	
+	}
+	else if (rfc)
+	{
+		vtmf = new BarnettSmartVTMF_dlog_GroupQR(crss, TMCG_DDH_SIZE,
+			TMCG_DLSE_SIZE);
+	}
+	else
+	{
 		vtmf = new BarnettSmartVTMF_dlog(crss, TMCG_DDH_SIZE, TMCG_DLSE_SIZE,
 			true); // with VTMF-verifiable generation of $g$ (VTMF-vgog)
+	}
 	// check the constructed VTMF instance
 	if (!vtmf->CheckGroup())
 	{
@@ -1007,6 +1029,8 @@ void run_instance
 		// key may be used to certify other keys, to sign data and has been
 		// split by a secret-sharing mechanism
 		dsaflags.push_back(0x01 | 0x02 | 0x10);
+		if (opt_timestamping)
+			dsaflags.push_back(0x08); // "This key may be used for timestamping"
 		// reuse key creation time as signature creation time
 		sigtime = ckeytime;
 	}
@@ -1014,6 +1038,8 @@ void run_instance
 	{
 		// key may be used to certify other keys and to sign data
 		dsaflags.push_back(0x01 | 0x02);
+		if (opt_timestamping)
+			dsaflags.push_back(0x08); // "This key may be used for timestamping"
 		// for a non-shared DSA primary key no common timestamp required 
 		sigtime = time(NULL); // current time
 	}
@@ -1868,6 +1894,7 @@ unsigned int gnunet_opt_wait = 5;
 unsigned int gnunet_opt_W = opt_W;
 int gnunet_opt_verbose = 0;
 int gnunet_opt_y = 0;
+int gnunet_opt_timestamping = 0;
 #endif
 
 void fork_instance
@@ -1988,6 +2015,11 @@ int main
 			"resilience of DKG protocol (threshold decryption)",
 			&gnunet_opt_t_resilience
 		),
+		GNUNET_GETOPT_option_flag('T',
+			"timestamping",
+			"state that the generated key is used for timestamping",
+			&gnunet_opt_timestamping
+		),
 		GNUNET_GETOPT_option_version(version),
 		GNUNET_GETOPT_option_flag('V',
 			"verbose",
@@ -2107,7 +2139,7 @@ int main
 		}
 		else if ((arg.find("--") == 0) || (arg.find("-v") == 0) ||
 			(arg.find("-h") == 0) || (arg.find("-V") == 0) ||
-			(arg.find("-y") == 0))
+			(arg.find("-y") == 0) || (arg.find("-T") == 0))
 		{
 			if ((arg.find("-h") == 0) || (arg.find("--help") == 0))
 			{
@@ -2131,6 +2163,8 @@ int main
 					" protocol (signature scheme)" << std::endl;
 				std::cout << "  -t INTEGER     resilience of tElG protocol" <<
 					" (threshold decryption)" << std::endl;
+				std::cout << "  -T, --timestamping state that the generated" <<
+					" key is used for timestamping" << std::endl;
 				std::cout << "  -v, --version  print the version number" <<
 					std::endl;
 				std::cout << "  -V, --verbose  turn on verbose output" <<
@@ -2154,6 +2188,8 @@ int main
 				opt_verbose++; // increase verbosity
 			if ((arg.find("-y") == 0) || (arg.find("--yaot") == 0))
 				opt_y = true;
+			if ((arg.find("-T") == 0) || (arg.find("--timestamping") == 0))
+				opt_timestamping = true;
 			continue;
 		}
 		else if (arg.find("-") == 0)
@@ -2181,35 +2217,7 @@ int main
 	opt_verbose = 2;
 	opt_e = 10800;
 	if (tmcg_mpz_wrandom_ui() % 2)
-	{
-		// sometimes test a non-FIPS CRS
-		crs = "crs|VMyMoPc2vb51ofxb4f2rebOSONnfhitfGcYxdav2D4wqBTeZrC"
-			"E000000000000000000000000000000000000000000000000000"
-			"0000000000000000000000000000000000000000000000000000"
-			"0000000000000000000000000000000000000000000000000000"
-			"0000000000000000000000000000000000000000000000000000"
-			"0000000000000000000000000000000000000000000000000000"
-			"0000000000000000000000000000000001|uDwReTJvQLAzuFRRO"
-			"6qqtd1MvZaQaSBxTzKOJjAbUA3|UQ51BEgx2Et2uVFsRwcj6wvIh"
-			"Vr78A3nWht7i9COt8bRjAd3bLFE4f2j6ueWjGusTW6n2mwczSpCV"
-			"f0jzpvou6Rt3B3AlNbJJC8i4436z63OiLco2wNsC8DxDq6mCe1Bi"
-			"Jeatdes9sV29tH9G4nMtI4RZi1Tcb4DZBJm1LehNGJVmXqznonEZ"
-			"UTAyHfuoxf02P0rc4z4rPRM8a80sqTwYLEzHfcJsTs9Qvp8jwbhb"
-			"VscxTGxItIkOWDTHm7H3JH5kMDRwGJBTeAmPztoOkGq7BOUlpKxi"
-			"NWe4fVKzn7CMyvVyQyvcbJwMP8WqtJfuZamgKASsekXDRt62JUC5"
-			"MCOuuCd|YakYaYak000000000000000000000000000000000000"
-			"0000000000000000000000000000000000000000000000000000"
-			"0000000000000000000000000000000000000000000000000000"
-			"0000000000000000000000000000000000000000000000000000"
-			"0000000000000000000000000000000000000000000000000000"
-			"0000000000000000000000000000000000000000000000000|";
-	}
-#else
-#ifdef DKGPG_TESTSUITE_Y
-	peers.push_back("TestY");
-	opt_y = true;
-	opt_verbose = 2;
-	opt_e = 10800;
+		opt_timestamping = true;
 	if (tmcg_mpz_wrandom_ui() % 2)
 	{
 		// sometimes test a non-FIPS CRS
@@ -2234,6 +2242,86 @@ int main
 			"0000000000000000000000000000000000000000000000000000"
 			"0000000000000000000000000000000000000000000000000|";
 	}
+//	else if (tmcg_mpz_wrandom_ui() % 2)
+//	{
+//		// sometimes test a CRS with fixed parameters from RFC 7919
+//		crs = "rfc-crs|m88HxBJpj9yKzDAlXe8tQ0jP0zSNm7oE71YSFt2ZQHiLVO"
+//			"kqnFJOK5EcaSLRHGmrtAhVybt7MarfGJf9DP5NTig8GXokeeHMiR"
+//			"00pxXnWmMmNd4C4JbsbmSKfOyPai66hMPXDybZprvk6E9Towmh8s"
+//			"rAAlz36OkTVJrZ5cKSEnpnDdd0BBwzvGDlstU5ZcuVwdVB7us5tX"
+//			"zyucSJBYoCEWf7VvqbJVYhe4GdvCczMCHGUsEKMsXsg5oBRHyQ6K"
+//			"TXX6PCJp9eo2kB4OvHgI5sZS0FMtzpuDlwcqYdLowuRIucwCFp9o"
+//			"PSBFSvO9TZRMcRXorL6mZQBglR9CcLSg7OSd2Vaa333uj1WH6HfB"
+//			"tkIaRzfwgn1P2XUGQZotOci8gdrvijNFyIdJE6k6qoVMog4SoNHo"
+//			"HZrq1CHx1QqfM2E0bXDAQNCkgzQO7zvcteMCn7xHBwNzQBg0AabM"
+//			"34izE4VrBwpLK3dNTos1CDmDCtTOQ7S0DHYOmSkkKYAmSWMf2bot"
+//			"Yd|O448yaeurZzAUbaNlp4Ri0MhVUjBt3u73VmE7wWHi8rAkhNQO"
+//			"cehA2cJIEAiddOQwaLkzIwYgIQpd9pZbhXgjrL48GuNKK8gMDV0P"
+//			"yltlOBOBoX629nwItEAKhUCnM33LgClbzImuvxs374juTOLZRQa5"
+//			"NzWYCNEkevmXoAE7OutbooV5ayUxd6swRk2moSFyJkaYxR2wlzzS"
+//			"JE9amP67GKYkxvIekmLp28JxbJUg68dFR7ABRGwL2u5idzD3AEll"
+//			"YCb9uZpP1N5XCSdq92wHj07gRzux6syJQHJfuTSDeSJT67uZuCj5"
+//			"cjSh4jmigJDluQfYOHi5qNiZbJAjL3hEJWFnI1WWxMVl8Y8paws9"
+//			"IDzpyLOVhWGk8DHuRhJM4LJvxrMgcz9Jec3N3QPFgPL2EPBdu8mv"
+//			"v0b8yViQKg170IlbaDBbNLUiC3zxoRpB6OYydayBzi5q05IIg1XM"
+//			"Uc2FvayPff1ogjuR0b6t6bRjhD3j06dmCOENNAH5OEGBKWIuRmJ|2|1|";
+//	}
+#else
+#ifdef DKGPG_TESTSUITE_Y
+	peers.push_back("TestY");
+	opt_y = true;
+	opt_verbose = 2;
+	opt_e = 10800;
+	if (tmcg_mpz_wrandom_ui() % 2)
+		opt_timestamping = true;
+	if (tmcg_mpz_wrandom_ui() % 2)
+	{
+		// sometimes test a non-FIPS CRS
+		crs = "crs|VMyMoPc2vb51ofxb4f2rebOSONnfhitfGcYxdav2D4wqBTeZrC"
+			"E000000000000000000000000000000000000000000000000000"
+			"0000000000000000000000000000000000000000000000000000"
+			"0000000000000000000000000000000000000000000000000000"
+			"0000000000000000000000000000000000000000000000000000"
+			"0000000000000000000000000000000000000000000000000000"
+			"0000000000000000000000000000000001|uDwReTJvQLAzuFRRO"
+			"6qqtd1MvZaQaSBxTzKOJjAbUA3|UQ51BEgx2Et2uVFsRwcj6wvIh"
+			"Vr78A3nWht7i9COt8bRjAd3bLFE4f2j6ueWjGusTW6n2mwczSpCV"
+			"f0jzpvou6Rt3B3AlNbJJC8i4436z63OiLco2wNsC8DxDq6mCe1Bi"
+			"Jeatdes9sV29tH9G4nMtI4RZi1Tcb4DZBJm1LehNGJVmXqznonEZ"
+			"UTAyHfuoxf02P0rc4z4rPRM8a80sqTwYLEzHfcJsTs9Qvp8jwbhb"
+			"VscxTGxItIkOWDTHm7H3JH5kMDRwGJBTeAmPztoOkGq7BOUlpKxi"
+			"NWe4fVKzn7CMyvVyQyvcbJwMP8WqtJfuZamgKASsekXDRt62JUC5"
+			"MCOuuCd|YakYaYak000000000000000000000000000000000000"
+			"0000000000000000000000000000000000000000000000000000"
+			"0000000000000000000000000000000000000000000000000000"
+			"0000000000000000000000000000000000000000000000000000"
+			"0000000000000000000000000000000000000000000000000000"
+			"0000000000000000000000000000000000000000000000000|";
+	}
+//	else if (tmcg_mpz_wrandom_ui() % 2)
+//	{
+//		// sometimes test a CRS with fixed parameters from RFC 7919
+//		crs = "rfc-crs|m88HxBJpj9yKzDAlXe8tQ0jP0zSNm7oE71YSFt2ZQHiLVO"
+//			"kqnFJOK5EcaSLRHGmrtAhVybt7MarfGJf9DP5NTig8GXokeeHMiR"
+//			"00pxXnWmMmNd4C4JbsbmSKfOyPai66hMPXDybZprvk6E9Towmh8s"
+//			"rAAlz36OkTVJrZ5cKSEnpnDdd0BBwzvGDlstU5ZcuVwdVB7us5tX"
+//			"zyucSJBYoCEWf7VvqbJVYhe4GdvCczMCHGUsEKMsXsg5oBRHyQ6K"
+//			"TXX6PCJp9eo2kB4OvHgI5sZS0FMtzpuDlwcqYdLowuRIucwCFp9o"
+//			"PSBFSvO9TZRMcRXorL6mZQBglR9CcLSg7OSd2Vaa333uj1WH6HfB"
+//			"tkIaRzfwgn1P2XUGQZotOci8gdrvijNFyIdJE6k6qoVMog4SoNHo"
+//			"HZrq1CHx1QqfM2E0bXDAQNCkgzQO7zvcteMCn7xHBwNzQBg0AabM"
+//			"34izE4VrBwpLK3dNTos1CDmDCtTOQ7S0DHYOmSkkKYAmSWMf2bot"
+//			"Yd|O448yaeurZzAUbaNlp4Ri0MhVUjBt3u73VmE7wWHi8rAkhNQO"
+//			"cehA2cJIEAiddOQwaLkzIwYgIQpd9pZbhXgjrL48GuNKK8gMDV0P"
+//			"yltlOBOBoX629nwItEAKhUCnM33LgClbzImuvxs374juTOLZRQa5"
+//			"NzWYCNEkevmXoAE7OutbooV5ayUxd6swRk2moSFyJkaYxR2wlzzS"
+//			"JE9amP67GKYkxvIekmLp28JxbJUg68dFR7ABRGwL2u5idzD3AEll"
+//			"YCb9uZpP1N5XCSdq92wHj07gRzux6syJQHJfuTSDeSJT67uZuCj5"
+//			"cjSh4jmigJDluQfYOHi5qNiZbJAjL3hEJWFnI1WWxMVl8Y8paws9"
+//			"IDzpyLOVhWGk8DHuRhJM4LJvxrMgcz9Jec3N3QPFgPL2EPBdu8mv"
+//			"v0b8yViQKg170IlbaDBbNLUiC3zxoRpB6OYydayBzi5q05IIg1XM"
+//			"Uc2FvayPff1ogjuR0b6t6bRjhD3j06dmCOENNAH5OEGBKWIuRmJ|2|1|";
+//	}
 #endif
 #endif
 
@@ -2357,6 +2445,13 @@ int main
 				" FIPS 186-4 section A.1.1.2)" << std::endl;
 		fips = true;
 	}
+	else if (TMCG_ParseHelper::cm(crs, "rfc-crs", '|'))
+	{
+		if (opt_verbose)
+			std::cerr << "INFO: verifying domain parameters (fixed by RFC" <<
+				" 7919)" << std::endl;
+		rfc = true;
+	}
 	else
 	{
 		std::cerr << "ERROR: common reference string (CRS) is not valid" <<
@@ -2611,6 +2706,11 @@ int main
 			"resilience of DKG protocol (threshold decryption)",
 			&gnunet_opt_t_resilience
 		),
+		GNUNET_GETOPT_option_flag('T',
+			"timestamping",
+			"state that the generated key is used for timestamping",
+			&gnunet_opt_timestamping
+		),
 		GNUNET_GETOPT_option_flag('V',
 			"verbose",
 			"turn on verbose output",
@@ -2691,8 +2791,10 @@ int main
 		{
 			std::cerr << "ERROR: protocol instance ";
 			if (WIFSIGNALED(wstatus))
+			{
 				std::cerr << pid[i] << " terminated by signal " <<
 					WTERMSIG(wstatus) << std::endl;
+			}
 			if (WCOREDUMP(wstatus))
 				std::cerr << pid[i] << " dumped core" << std::endl;
 			ret = -1; // fatal error
@@ -2700,9 +2802,11 @@ int main
 		else if (WIFEXITED(wstatus))
 		{
 			if (opt_verbose)
+			{
 				std::cerr << "INFO: protocol instance " << pid[i] <<
 					" terminated with exit status " << WEXITSTATUS(wstatus) <<
 					std::endl;
+			}
 			if (WEXITSTATUS(wstatus))
 				ret = -2; // error
 		}
