@@ -1125,6 +1125,9 @@ int main
 	// in the possession of more than one person.
 	if ((allflags & 0x80) == 0x80)
 		std::cout << "G";
+	// This key may be used for timestamping. [draft RFC 4880bis]
+	if ((allflags & 0x0800) == 0x0800)
+		std::cout << "T";
 	if (allflags == 0x00)
 		std::cout << "undefined";
 	std::cout << std::endl;
@@ -1352,7 +1355,10 @@ int main
 	if (opt_p)
 	{
 		if (prv->Weak(opt_verbose) && opt_verbose)
-			std::cerr << "WARNING: weak private primary key detected" << std::endl;
+		{
+			std::cerr << "WARNING: weak private primary key detected" <<
+				std::endl;
+		}
 		switch (prv->pkalgo)
 		{
 			case TMCG_OPENPGP_PKALGO_RSA:
@@ -1393,7 +1399,10 @@ int main
 	for (size_t j = 0; j < primary->userids.size(); j++)
 	{
 		std::cout << "OpenPGP User ID: " << std::endl << "\t";
-		std::cout << primary->userids[j]->userid_sanitized << std::endl;
+		std::cout << primary->userids[j]->userid_sanitized;
+		if (!primary->userids[j]->valid)
+			std::cout << " [INVALID]";
+		std::cout << std::endl;
 	}
 	// show information w.r.t. (valid) subkeys
 	for (size_t j = 0; j < primary->subkeys.size(); j++)
@@ -1459,6 +1468,9 @@ int main
 		// in the possession of more than one person.
 		if ((allflags & 0x80) == 0x80)
 			std::cout << "G";
+		// This key may be used for timestamping. [draft RFC 4880bis]
+		if ((allflags & 0x0800) == 0x0800)
+			std::cout << "T";
 		if (allflags == 0x00)
 			std::cout << "undefined";
 		std::cout << std::endl;
